<?php
/**
 * @package      FoodTime
 * @author       XtraPunch.com [www.xtrapunch.com]
 * @copyright    Copyright (c) 2015, XtraPunch.com
 * @license      MIT License

 * @Based on TwentyOfTime WordPress theme by Friso van Dijk [www.frisovandijk.com]
 * @copyright    Copyright (c) 2015, Friso van Dijk
 * @license      http://www.frisovandijk.com/public/MIT-LICENSE.txt
 */

//* Load the Genesis framework
include_once( get_template_directory() . '/lib/init.php' );

//* Child theme defenitions
define( 'CHILD_THEME_NAME', 'Food Time' );
define( 'CHILD_THEME_URL', 'http://www.foodbloggingguide.com/' );
define( 'CHILD_THEME_VERSION', '1.0' );

//* Add HTML5 markup structure
add_theme_support( 'html5' );
//* Add viewport meta tag for mobile browsers
add_theme_support( 'genesis-responsive-viewport' );
//* Add support for custom background
add_theme_support( 'custom-background' );
//* Add 3 footer widgets
add_theme_support( 'genesis-footer-widgets', 3 );

/** Custom image sizes */
add_image_size( 'Post-Image', 1200, 600, TRUE );

// Move breadcrumbs
remove_action('genesis_before_loop', 'genesis_do_breadcrumbs');
add_action('genesis_before_content', 'genesis_do_breadcrumbs');

//* Add support for genesis custom header
//add_theme_support( 'genesis-custom-header', array( 'width' => 360, 'height' => 100 ) );

//* Add support for custom header
add_theme_support( 'custom-header', array(
	'flex-height'     => true,
	'flex-width'     => true,
	'width'           => 360,
	'height'          => 100,
	'header-selector' => '.site-title a',
	'header-text'     => false,
) );

/**
 * Filter genesis_seo_site_title to use an image for logo instead of background image
 * The genesis_seo_site_title function is located in genesis/lib/structure/header.php
 * @link http://blackhillswebworks.com/?p=4144
 */

function xtrapunch_filter_genesis_seo_site_title( $title, $inside ){
	 
	$child_inside = sprintf( '<a href="%s" title="%s"><img src="%s" title="%s" alt="%s"/></a>', trailingslashit( home_url() ), esc_attr( get_bloginfo( 'name' ) ), get_header_image(), esc_attr( get_bloginfo( 'name' ) ), esc_attr( get_bloginfo( 'name' ) ) );
	$title = str_replace( $inside, $child_inside, $title );
	return $title;
}
	
// If Header image defined
if ( get_header_image() ) {
	add_filter( 'genesis_seo_title', 'xtrapunch_filter_genesis_seo_site_title', 10, 2 );
}

// Remove site tagline 
remove_action( 'genesis_site_description', 'genesis_seo_site_description' );

/*--------------------
function xtrapunch_header_css_attr( $attributes ) {
 	// add original plus extra CSS classes
	$attributes['class'] .= ' only-header ';
	return $attributes;
}

// If Header Widget Active - Add Class to the Header
if ( function_exists('is_active_sidebar') && !is_active_sidebar ( 'header-right' ) ) {
	add_filter( 'genesis_attr_title-area', 'xtrapunch_header_css_attr' );
}
------------------- */

//* Code to Display Featured Image on top of the post
add_action( 'genesis_before_entry', 'tot_featured_post_image', 8 );
function tot_featured_post_image() {
	if (!is_singular('post') && !is_home() && !is_category())  return;
	echo '<a class="top-image" href="'. get_the_permalink() .'">';
	the_post_thumbnail('Post-Image');
	echo '</a>';
}

//* Modify the Genesis content limit read more link
//add_filter( 'excerpt_more', 'tot_read_more_link' );
//add_filter( 'the_content_more_link', 'tot_read_more_link' );
//add_filter( 'get_the_content_more_link', 'tot_read_more_link' );
function tot_read_more_link() {
	return '<br/><a class="more-link" href="' . get_permalink() . '">Continue reading &#187;</a>';
}

//* Attaches the Read More link to custom excerpts
// add_filter( 'get_the_excerpt', 'xtra_do_excerpt_read_more_link' );
function xtra_do_excerpt_read_more_link( $output ) {
    global $post;
    if ( $post->post_excerpt != '' ) {
        $output .= tot_read_more_link();
    }
    return $output;
}

//* Customize the post info function
add_filter( 'genesis_post_info', 'tot_post_info_filter' );
function tot_post_info_filter($post_info) {
	if ( ! is_page() ) {
		$post_info = '&mdash; by [post_author] on [post_date] [post_comments] [post_edit]';
		return $post_info;
	}
}

//* Customize the post meta function
add_filter( 'genesis_post_meta', 'tot_post_meta_filter' );
function tot_post_meta_filter($post_meta) {
	if ( !is_page() ) {
		$post_meta = '[post_categories before="Category: "]';
		$post_meta .= '[post_tags before="Tagged: "]';
		return $post_meta;
	}
}

//* Remove Post Meta
//remove_action( 'genesis_entry_footer', 'genesis_post_meta' );

//* Remove the primary navigation menu
//remove_action( 'genesis_after_header', 'genesis_do_nav' );


//* Sticky Footer Functions
add_action( 'genesis_before_header', 'stickyfoot_wrap_begin');
function stickyfoot_wrap_begin() {
	echo '<div class="page-wrap">';
}

add_action( 'genesis_before_footer', 'stickyfoot_wrap_end');
function stickyfoot_wrap_end() {
	echo '</div><!-- page-wrap -->';
}

//* Customize the entire footer
remove_action( 'genesis_footer', 'genesis_do_footer' );
add_action( 'genesis_footer', 'xtra_custom_footer' );
function xtra_custom_footer() {
	if (is_front_page()) { ?>
	<p>&copy; 2015 <a href="<?php echo CHILD_THEME_URL; ?>" target="_blank"><?php echo get_bloginfo('name'); ?> &mdash; Powered by WordPress & <?php echo CHILD_THEME_NAME; ?> Theme</a></p>
<?php } else {?>
	<p>&copy; 2015 <?php echo get_bloginfo('name'); ?> &mdash; <?php echo get_bloginfo('description'); ?></p>

<?php }
}